from scranking.Swimmer import Swimmer


def test_swimmer():
    url = 'https://www.swimcloud.com/swimmer/549377/'
    swimmer = Swimmer(url)

    soup = swimmer.get_soup()
    assert swimmer.get_http_status() == 200
    assert swimmer.get_name(soup) == "Seungjoon Ahn"



import requests
from bs4 import BeautifulSoup


class Swimmer:
    def __init__(self, url):
        self.url = url

    def get_http_status(self):
        response = requests.get(self.url)
        if not response:
            return "Connection fail"
        else:
            return response.status_code

    def get_soup(self):
        response = requests.get(self.url)
        soup = BeautifulSoup(response.content, 'html.parser')
        if not soup:
            return "Not possible to parse"
        else:
            return soup

    def save_soup_to_file(self, soup, filename):
        with open(filename, "w") as f:
            f.write(str(soup))

    def get_name(self, soup):
        name = soup.find('title')
        titleString = name.string
        s1 = titleString.replace("| Swimcloud", "", 1).replace('\n', '').strip()  # noqa

        if not s1:
            return None
        else:
            return s1

    def get_info(self, html):
        newsoup = BeautifulSoup(html, 'html.parser')
        hometown = newsoup.find('li').get_text()
        print(hometown)
        university = newsoup.find('a').get_text()
        print(university)

        social_links = newsoup.find_all('a', class_='btn-icon-plain')
        for link in social_links:
            title = link.get('title')
            if 'Twitter' in title:
                twitter = link['href']
                print(twitter)
            elif 'Instagram' in title:
                instagram = link['href']
                print(instagram)


url = 'https://www.swimcloud.com/swimmer/549377/'
swimmer = Swimmer(url)
http_status = swimmer.get_http_status()
soup = swimmer.get_soup()
swimmer.save_soup_to_file(soup, "schml.txt")
infohtml = '<ul class="o-list-inline o-list-inline--dotted"><li>Katy, TX</li><li><a href="/team/283">Columbia University</a></li><li><ul class="o-list-inline"><li class="u-mr-"><a class="btn-icon-plain" href="https://twitter.com/SeungjoonA" target="_blank" title="Twitter"><i class="fab fa-twitter"></i><span class="u-is-hidden-visually">Seungjoon Ahn on Twitter</span></a></li><li><a class="btn-icon-plain" href="https://instagram.com/seun_g01" target="_blank" title="Instagram"><i class="fab fa-instagram"></i><span class="u-is-hidden-visually">Seungjoon Ahn on Instagram</span></a></li></ul></li></ul>'  # noqa

name = swimmer.get_name(soup)
print(url)
print("HTTP status:", http_status)
print(name)
swimmer.get_info(infohtml)



import unittest
from unittest.mock import MagicMock, patch
from scranking.Swimmer import Swimmer
from bs4 import BeautifulSoup


class TestSwimmer(unittest.TestCase):
    @patch('requests.get')
    def test_get_http_status_if_response(self, mock_get):
        swimmer = Swimmer("http://www.example.com")
        mock_response = MagicMock()
        mock_response.status_code = 200
        mock_get.return_value = mock_response

        self.assertEqual(swimmer.get_http_status(), 200)

    @patch('requests.get')
    def test_get_http_status_if_not_response(self, mock_get):
        swimmer = Swimmer("http://www.example.com")
        mock_response = MagicMock()
        mock_response.status_code = 200
        mock_get.return_value = None

        self.assertEqual(swimmer.get_http_status(), "Connection fail")

    @patch('requests.get')
    def test_get_soup_if_soup(self, mock_get):
        swimmer = Swimmer("http://www.example.com")
        mock_response = MagicMock()
        mock_response.content = b'<html><body></body></html>'
        mock_get.return_value = mock_response

        soup = swimmer.get_soup()

        self.assertIsInstance(soup, BeautifulSoup)

    def test_get_name_with_valid_input(self):
        swimmer = Swimmer("https://example.com")
        html_doc = '<html><head><title>Sample Title ' '| Swimcloud</title></head></html>'  # noqa
        soup = BeautifulSoup(html_doc, 'html.parser')

        # Call the function and check the output
        self.assertEqual(swimmer.get_name(soup), "Sample Title")

    def test_get_name_with_not_valid_input(self):
        swimmer = Swimmer("https://example.com")
        html_doc = '<html><head><title> | Swimcloud</title></head></html>'
        soup = BeautifulSoup(html_doc, 'html.parser')

        # Call the function and check the output
        self.assertEqual(swimmer.get_name(soup), None)
